pub struct RetrySettings {
pub amount: u64,
pub delay: Duration,
}Expand description
Settings for retrying when API rate limit is reached.
Amount and delay are set to zero by default, you will need to change both to enable retrying.
Check different BlockFrost plans and their limits at https://blockfrost.io/#pricing.
Note: You can disable delay between retries with Duration::ZERO.
Fields
amount: u64delay: DurationImplementations